==> generator-jumper-0.0.3.tgz: package/Russian.md <==
# generator-jumper

Генератор для [Yeoman](http://yeoman.io) от Jump Creative Agency.


## Вводное руководство

### Что такое Yeoman?

Yeoman — инструмент для инициализации проектов (scaffolder). Подробнее можно 
узнать [здесь](http://yeoman.io).
Для его установки выполните команду:

```
$ npm install -g yo
```

Yeoman подразумевает использование [Grunt](http://gruntjs.com) и
[Bower](http://bower.io).

### generator-jumper

Для установки генератора «Jumper» из npm установите `yo` и выполните команду

```
$ npm install -g generator-jumper
```

Для инициализации нового проекта запустите генератор командой

```
$ yo jumper
```

### Компоненты генератора

Изначально генератор включает в себя [HTML5Boilerplate](http://h5bp.com) и [jQuery](http://jquery.com) последней версии. Также на выбор предоставляется возможность разворачивания фреймворка [Twitter Bootstrap 3](http://getbootstrap.com) или [Zurb Foundation 4](http://foundation.zurb.com). Вы можете отказаться от использования фреймворка — в таком случае css-файл проекта будет содержать Normalize.css.
Выбрав фреймворк вы можете согласиться с использованием Sass-версии выбранного фреймворка, или отказаться от неё и получить его css-версию.
Следующим шагом инициализации является выбор некоторых дополнительных компонентов:

* Modernizr (пока только как генератор для Grunt, по-умолчанию включено)
* Handlebars.js (по-умолчанию отключено)
* Autoprefixer (как таск для Grunt, по-умолчанию включено)
* Jumper SCSS — набор миксинов, используемых авторами генератора (по-умолчанию отключено)

Затем генератор предложит использовать js-библиотеку fastClick для
исключения задержки тапов в тач-устройствах (по-умолчанию включено). И
последнее, возможность включить в html-файл кросс-браузерный набор
фавиконок (по-умолчанию отключено).

## Лицензия

[Лицензия MIT](http://en.wikipedia.org/wiki/MIT_License)

## Информация для контрибьютеров

Мы будем вам благодарны за помощь в разработке. Если вы знаете как
исправить существующую ошибку или нашли новую, просим вас ответвиться, создав 
тематическую ветку и, сделав необходимые правки, отправить нам пулл-реквест.

==> generator-jumper-0.0.4.tgz: package/Russian.md <==
# generator-jumper

Генератор для [Yeoman](http://yeoman.io) от Jump Creative Agency.


## Вводное руководство

### Что такое Yeoman?

Yeoman — инструмент для инициализации проектов (scaffolder). Подробнее можно 
узнать [здесь](http://yeoman.io).
Для его установки выполните команду:

```
$ npm install -g yo
```

Yeoman подразумевает использование [Grunt](http://gruntjs.com) и
[Bower](http://bower.io).

### generator-jumper

Для установки генератора «Jumper» из npm установите `yo` и выполните команду

```
$ npm install -g generator-jumper
```

Для инициализации нового проекта запустите генератор командой

```
$ yo jumper
```

### Компоненты генератора

Изначально генератор включает в себя [HTML5Boilerplate](http://h5bp.com) и [jQuery](http://jquery.com) последней версии. Также на выбор предоставляется возможность разворачивания фреймворка [Twitter Bootstrap 3](http://getbootstrap.com) или [Zurb Foundation 4](http://foundation.zurb.com). Вы можете отказаться от использования фреймворка — в таком случае css-файл проекта будет содержать Normalize.css.
Выбрав фреймворк вы можете согласиться с использованием Sass-версии выбранного фреймворка, или отказаться от неё и получить его css-версию.
Следующим шагом инициализации является выбор некоторых дополнительных компонентов:

* [Modernizr](http://modernizr.com) (пока только как [генератор для Grunt](https://npmjs.org/package/grunt-modernizr), по-умолчанию включено)
* [Handlebars.js](http://handlebarsjs.com) (по-умолчанию отключено)
* [Autoprefixer](https://github.com/ai/autoprefixer) (как [таск для Grunt](https://npmjs.org/package/grunt-autoprefixer), по-умолчанию включено)

Затем генератор предложит использовать js-библиотеку [fastClick](https://github.com/ftlabs/fastclick) для
исключения задержки тапов в тач-устройствах (по-умолчанию включено). И
последнее, возможность включить в html-файл кросс-браузерный набор
фавиконок (по-умолчанию отключено).

## Лицензия

[Лицензия MIT](http://en.wikipedia.org/wiki/MIT_License)

## Информация для контрибьюторов

Мы будем вам благодарны за помощь в разработке. Если вы знаете как
исправить существующую ошибку или нашли новую, просим, создав 
тематическую ветку и, сделав необходимые правки, отправить нам пулл-реквест или написать об ошибке в [Issue](https://github.com/lancedikson/generator-jumper/issues).

## В планах

Планирую добавить опциональную установку следующих тасков и плагинов:

* [grunt-webfont](https://npmjs.org/package/grunt-webfont)
* [grunt-csscomb](https://npmjs.org/package/grunt-csscomb)
* [grunt-pagespeed](https://github.com/jrcryer/grunt-pagespeed)
